---
title: '[공지] 포트원 애널리틱스 이슈 공지(조치완료)'
category: 공지사항
tags:
  - 공지사항
datetime: 2023-12-11T15:00:00.000Z
---

안녕하세요. 포트원 고객지원팀입니다.

현재 당사 애널리틱스 서비스 데이터가 정상적으로 업데이트 되지 않는 이슈가 발견되어 현재 이슈 **조지완료** 되었음을 공지드립니다.

다시 한번 서비스 이용에 불편을 드려 죄송합니다.

상세

---

1. 장애 현상 : 포트원 관리자콘솔 애널리틱스 내 데이터가 정상적으로 업데이트 되지 않음
2. 장애 대상 : 포트원 관리자콘솔 > 애널리틱스

- 결제, 본인인증, API 등 결제에는 영향없음

3\. 영향시간 : 2023-12-11 21:05 \~ 13:29 (조치완료)

---

감사합니다.
